<?php
/*
Plugin Name: Multi-X Bar - Custom Theme
Plugin URI: http://www.icprojects.net/multi-x-bar-custom-theme.html
Description: This plugin adds custom theme to Multi-X Bar.
Author: Ivan Churakov
Author URI: http://www.icprojects.net/about
Version: 1.14
*/
define('MULTIXTHEME_VERSION', 1.14);
define('MULTIXTHEME_ID', 'custom_theme');

if (function_exists('load_plugin_textdomain')) {
	load_plugin_textdomain('multix', false, dirname(plugin_basename(__FILE__)).'/languages/');
}
add_action('plugins_loaded', 'multixtheme_init');

function multixtheme_init() {
	if (class_exists('multix_class') && class_exists('multix_module')) {
		class customtheme_module extends multix_module {
			var $background_repeats = array(
				"none" => "None",
				"repeat" => "Repeat",
				"repeat-x" => "Repeat-X",
				"repeat-y" => "Repeat-Y"
			);
			var $font_schemes = array(
				"light" => "Light",
				"dark" => "Dark"
			);
			
			function __construct() {
				global $multix;
				
				$this->options = array (
					"background_color" => "#222222",
					"background_url" => "",
					"background_repeat" => "none",
					"font_scheme" => "light"
				);

				$this->get_options();
					
				add_filter('multix_check_options', array(&$this, 'check_options'), 10, 2);
				add_filter('multix_themes', array(&$this, 'multix_themes'));
				
				if (is_admin()) {
					add_action('admin_enqueue_scripts', array(&$this, 'admin_enqueue_scripts'));
					add_action('multix_echo_options_box', array(&$this, 'admin_settings'));
					add_action('multix_save_options', array(&$this, 'save_options'));
				} else {
					if (!empty($multix) && $multix->options['theme'] == MULTIXTHEME_ID) {
						add_action('multix_front_header_style', array(&$this, 'front_header_style'), 9);
					}
				}
			}

			function admin_enqueue_scripts() {
				wp_enqueue_script("jquery");
				if (isset($_GET['page']) && $_GET['page'] == 'multix') {
					wp_enqueue_style('wp-color-picker');
					wp_enqueue_script('wp-color-picker');
				}
			}

			function multix_themes($themes) {
				$themes[MULTIXTHEME_ID] = array("title" => __('Custom Theme', 'multix'), "font_scheme" => $this->options['font_scheme'], "class" => "multix_custom_theme");
				return $themes;
			}

			function check_options($_errors, $active_modules) {
				global $multix;
				$errors = array();
				if (!empty($multix) && $multix->options['theme'] == MULTIXTHEME_ID) {
					if (!preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $this->options['background_url']) && strlen($this->options['background_url']) > 0) $errors[] =  __('Background Image URL must be valid URL', 'multix');
					if ($this->get_rgb($this->options['background_color']) === false) $errors[] = __('Background color must be valid value', 'multix');
				}
				return array_merge($_errors, $errors);
			}

			function admin_settings() {
				global $wpdb;
				print ('
					<div class="postbox" id="multix-settings-'.$this->module['id'].'">
						<h3 class="hndle" style="cursor: default;"><span>'.__('Custom Theme Settings', 'multix').'</span></h3>
						<div class="inside">
							<p class="description">'.__('In this section you can customize Multi-X Bar theme. Do not forget to select "Custom Theme" in "General Settings" section.', 'multix').'</p>
							<table class="multix_useroptions">
								<tr>
									<th>'.__('Background color', 'multix').':</th>
									<td>
										<input class="multix-color" type="text" id="'.$this->field_name('background_color').'" name="'.$this->field_name('background_color').'" value="'.htmlspecialchars($this->options['background_color'], ENT_QUOTES).'" style="width: 80px; text-align: right;">
										<br /><em>'.__('Please set desired background color.', 'multix').'</em>
									</td>
								</tr>
								<tr>
									<th>'.__('Background image', 'multix').':</th>
									<td><input type="text" id="'.$this->field_name('background_url').'" name="'.$this->field_name('background_url').'" value="'.htmlspecialchars($this->options['background_url'], ENT_QUOTES).'" class="widefat">
									<br /><em>'.__('Enter URL of background image.', 'multix').'</em></td>
								</tr>
								<tr>
									<th>'.__('Image repeat', 'multix').':</th>
									<td>
										<select id="'.$this->field_name('background_repeat').'" name="'.$this->field_name('background_repeat').'">');
				foreach ($this->background_repeats as $key => $value) {
					echo '
											<option value="'.$key.'"'.($this->options['background_repeat'] == $key ? ' selected="selected"' : '').'>'.$value.'</option>';
				}
				print ('
										</select>
										<br /><em>'.__('Please select background image repeat parameter.', 'multix').'</em>
									</td>
								</tr>
								<tr>
									<th>'.__('Font color scheme', 'multix').':</th>
									<td>
										<select id="'.$this->field_name('font_scheme').'" name="'.$this->field_name('font_scheme').'">');
				foreach ($this->font_schemes as $key => $value) {
					echo '
											<option value="'.$key.'"'.($this->options['font_scheme'] == $key ? ' selected="selected"' : '').'>'.$value.'</option>';
				}
				print ('
										</select>
										<br /><em>'.__('Please select font color scheme.', 'multix').'</em>
									</td>
								</tr>
							</table>
							<div class="alignright">
							<input type="submit" class="multix_button button-primary" name="submit" value="'.__('Update Settings', 'multix').'">
							</div>
						</div>
					</div>
					<script>
						jQuery(document).ready(function() {
							jQuery(".multix-color").wpColorPicker();
						});
					</script>
					');
			}
				
			function save_options($active_modules = array()) {
				global $wpdb;
				$this->populate_options();
				$this->update_options();
			}

			function front_header_style($active_modules = null) {
				echo $this->get_stylesheet();
			}

			function get_stylesheet() {
				$from = $this->get_rgb($this->options['background_color']);
				$total = $from['r']+$from['g']+$from['b'];
				if ($total == 0) $total = 1;
				$to = array();
				$to['r'] = max(0, $from['r']-intval(48*$from['r']/$total));
				$to['g'] = max(0, $from['g']-intval(48*$from['g']/$total));
				$to['b'] = max(0, $from['b']-intval(48*$from['b']/$total));
				$to_color = '#'.($to['r'] < 16 ? '0' : '').dechex($to['r']).($to['g'] < 16 ? '0' : '').dechex($to['g']).($to['b'] < 16 ? '0' : '').dechex($to['b']);
				$from_color = $this->options['background_color'];
				
				$stylesheet = '
/* Custom Theme Color Scheme */
.multix_custom_theme {
	border-color: '.$to_color.';
	background-color: '.$to_color.';
	background: -webkit-gradient(linear, left top, left bottom, from('.$from_color.'), to('.$to_color.'));
	background: -webkit-linear-gradient(top, '.$from_color.', '.$to_color.');
	background: -moz-linear-gradient(top, '.$from_color.', '.$to_color.');
	background: -ms-linear-gradient(top, '.$from_color.', '.$to_color.');
	background: -o-linear-gradient(top, '.$from_color.', '.$to_color.');
	'.(!empty($this->options['background_url']) ? '
	background-image: url('.$this->options['background_url'].');
	background-repeat: '.$this->options['background_repeat'].';' : '').'
}
div.multix_custom_theme_container {
	background: '.$to_color.';
	background-color: rgba('.$to['r'].','.$to['g'].','.$to['b'].',0.95);
}
.multix_custom_theme .multix-menu-mobile > ul,
.multix_custom_theme .multix-menu-desktop ul ul{
	background-color: '.$from_color.';
	background-color: rgba('.$from['r'].','.$from['g'].','.$from['b'].',0.9);
}';
				return $stylesheet;
			}

			function get_rgb($_color) {
				if (strlen($_color) != 7 && strlen($_color) != 4) return false;
				$color = preg_replace('/[^#a-fA-F0-9]/', '', $_color);
				if (strlen($color) != strlen($_color)) return false;
				if (strlen($color) == 7) list($r, $g, $b) = array($color[1].$color[2], $color[3].$color[4], $color[5].$color[6]);
				else list($r, $g, $b) = array($color[1].$color[1], $color[2].$color[2], $color[3].$color[3]);
				return array("r" => hexdec($r), "g" => hexdec($g), "b" => hexdec($b));
			}
		}
		if (!defined('MULTIX_VERSION') || MULTIX_VERSION < 2.00) {
			add_action('admin_notices', 'multixtheme_oldmultix');
		} else {
			$customtheme_module = new customtheme_module();
		}
	} else {
		add_action('admin_notices', 'multixtheme_nomultix');
	}
}

function multixtheme_nomultix() {
	echo '
		<div class="updated"><p>'.__('Please activate <strong>Multi-X Bar</strong> plugin to use <strong>Multi-X Bar - Custom Theme</strong>. Get your copy of Multi-X Bar <strong><a href="http://codecanyon.net/item/multix-bar/3741886?ref=ichurakov">here</a></strong>.', 'multix').'</p></div>';
}

function multixtheme_oldmultix() {
	echo '
		<div class="updated"><p>'.__('<strong>Multi-X Bar - Custom Theme</strong> requires <strong>Multi-X Bar</strong> ver <strong>2.00</strong> or higher to be installed. Get latest copy of Multi-X Bar <strong><a href="http://codecanyon.net/item/multix-bar/3741886?ref=ichurakov">here</a></strong>.', 'multix').'</p></div>';
}

?>